summaryrefslogtreecommitdiff
path: root/django/http/multipartparser.py
diff options
context:
space:
mode:
authorEric Urban <hydrogen18@gmail.com>2013-05-17 19:49:33 -0400
committerEric Urban <hydrogen18@gmail.com>2013-05-17 19:49:33 -0400
commitc278e56bafc8b2740f01e53fc5ce3650806c04ad (patch)
tree9a43fb61992cf5f2237380780b5997fa1ab9c07a /django/http/multipartparser.py
parentf54a8880d78f4b0b37371b0b295b2b1e73c8b67f (diff)
Corrected documentation on the constructor arguments of MultiPartParser
Diffstat (limited to 'django/http/multipartparser.py')
-rw-r--r--django/http/multipartparser.py11
1 files changed, 6 insertions, 5 deletions
diff --git a/django/http/multipartparser.py b/django/http/multipartparser.py
index 0e999f2ded..26e10da1a2 100644
--- a/django/http/multipartparser.py
+++ b/django/http/multipartparser.py
@@ -48,9 +48,9 @@ class MultiPartParser(object):
The standard ``META`` dictionary in Django request objects.
:input_data:
The raw post data, as a file-like object.
- :upload_handler:
- An UploadHandler instance that performs operations on the uploaded
- data.
+ :upload_handlers:
+ A list of UploadHandler instances that perform operations on the uploaded
+ data.
:encoding:
The encoding with which to treat the incoming data.
"""
@@ -113,14 +113,15 @@ class MultiPartParser(object):
if self._content_length == 0:
return QueryDict('', encoding=self._encoding), MultiValueDict()
# See if the handler will want to take care of the parsing.
# This allows overriding everything if somebody wants it.
for handler in handlers:
result = handler.handle_raw_input(self._input_data,
self._meta,
self._content_length,
self._boundary,
encoding)
+ #Check to see if it was handled
if result is not None:
return result[0], result[1]
@@ -113,14 +113,15 @@ class MultiPartParser(object):
if self._content_length == 0:
return QueryDict('', encoding=self._encoding), MultiValueDict()
- # See if the handler will want to take care of the parsing.
- # This allows overriding everything if somebody wants it.
+ # See if any of the handlers take care of the parsing.
+ # This allows overriding everything if need be.
for handler in handlers:
result = handler.handle_raw_input(self._input_data,